@@ -2,9 +2,9 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '2.81';
+$VERSION = '2.84';
 
-require 5.004;
+require 5.008;
 use strict;
 use warnings;
 use Carp;
@@ -1784,6 +1784,10 @@ sub _write_config_with_a_made_fh
     else
     {
         seek( $fh, 0, SEEK_SET() );
+        # Make sure to keep the previous junk out.
+        # See:
+        # https://rt.cpan.org/Public/Bug/Display.html?id=103496
+        truncate( $fh, 0 );
         $self->OutputConfigToFileHandle($fh, $parms{-delta});
         seek( $fh, 0, SEEK_SET() );
     } # end if
@@ -3166,8 +3170,13 @@ Development discussion occurs on the mailing list
 config-inifiles-dev@lists.sourceforge.net, which you can subscribe
 to by going to the project web site (link above).
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+=head1 LICENSE
+
+This software is copyright (c) 2000 by Scott Hutton and the rest of the
+Config::IniFiles contributors.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
